@@ -3,21 +3,19 @@
 
 set -e
 
-readonly SWIFTTAG=6.1.3
-readonly YAMS_VERSION=5.0.6
+readonly SWIFTTAG=6.2.3
 readonly SWIFT_ARGUMENT_PARSER_VERSION=1.4.0
 readonly SWIFT_CRYPTO_VERSION=3.0.0
 readonly SWIFT_ATOMICS_VERSION=1.2.0
 readonly SWIFT_COLLECTIONS_VERSION=1.1.3
 readonly SWIFT_NUMERICS_VERSION=1.0.2
-readonly SWIFT_SYSTEM_VERSION=1.3.0
+readonly SWIFT_SYSTEM_VERSION=1.5.0
 readonly SWIFT_NIO_VERSION=2.65.0
-#readonly SWIFT_NIO_SSL_VERSION=2.15.0
 readonly SWIFT_CERTIFICATES_VERSION=1.0.1
 readonly SWIFT_ASN1_VERSION=1.0.0
-#readonly WASMKIT_VERSION=0.1.2
-#readonly WASI_VERSION=22
-readonly SWIFT_FORMAT_VERSION=601.0.0
+readonly WASMKIT_VERSION=0.1.6
+#readonly WASI_VERSION=24
+readonly SWIFT_FORMAT_VERSION=602.0.0
 readonly SWIFT_TOOLCHAIN_SQLITE_VERSION=1.0.1
 readonly SWIFT_ASYNC_ALGORITHMS_VERSION=1.0.1
 readonly SWIFT_LOG_VERSION=1.5.4
@@ -47,6 +45,17 @@ mkdir swift
 tar -C swift -zxf ../swiftlang_$SWIFTTAG.orig-swift.tar.gz --strip-components=1
 
 
+if [ -f "../swiftlang_$SWIFTTAG.orig-swift-build.tar.gz" ];
+then
+    echo "Found existing swiftlang_$SWIFTTAG.orig-swift-build.tar.gz"
+else
+    wget https://github.com/swiftlang/swift-build/archive/swift-$SWIFTTAG-RELEASE.tar.gz
+    mv -f swift-$SWIFTTAG-RELEASE.tar.gz ../swiftlang_$SWIFTTAG.orig-swift-build.tar.gz
+fi
+mkdir swift-build
+tar -C swift-build -xzf ../swiftlang_$SWIFTTAG.orig-swift-build.tar.gz --strip-components=1
+
+
 if [ -f "../swiftlang_$SWIFTTAG.orig-swift-corelibs-libdispatch.tar.gz" ];
 then
     echo "Found existing swiftlang_$SWIFTTAG.orig-swift-corelibs-libdispatch.tar.gz"
@@ -234,17 +243,6 @@ mkdir swift-syntax
 tar -C swift-syntax -xzf ../swiftlang_$SWIFTTAG.orig-swift-syntax.tar.gz --strip-components=1
 
 
-if [ -f "../swiftlang_$SWIFTTAG.orig-yams.tar.gz" ];
-then
-    echo "Found existing swiftlang_$SWIFTTAG.orig-yams.tar.gz"
-else
-    wget https://github.com/jpsim/Yams/archive/$YAMS_VERSION.tar.gz
-    mv -f $YAMS_VERSION.tar.gz ../swiftlang_$SWIFTTAG.orig-yams.tar.gz
-fi
-mkdir yams
-tar -C yams -xzf ../swiftlang_$SWIFTTAG.orig-yams.tar.gz --strip-components=1
-
-
 if [ -f "../swiftlang_$SWIFTTAG.orig-swift-crypto.tar.gz" ];
 then
     echo "Found existing swiftlang_$SWIFTTAG.orig-swift-crypto.tar.gz"
@@ -383,17 +381,6 @@ fi
 unzip -q ../swiftlang_$SWIFTTAG.orig-swift-nio.zip
 mv swift-nio-$SWIFT_NIO_VERSION swift-nio
 
-
-#if [ -f "../swiftlang_$SWIFTTAG.orig-swift-nio-ssl.zip" ];
-#then
-    #echo "Found existing swiftlang_$SWIFTTAG.orig-swift-nio-ssl.zip"
-#else
-    #wget https://github.com/apple/swift-nio-ssl/archive/refs/tags/$SWIFT_NIO_SSL_VERSION.zip
-    #mv -f $SWIFT_NIO_SSL_VERSION.zip ../swiftlang_$SWIFTTAG.orig-swift-nio-ssl.zip
-#fi
-#unzip -q ../swiftlang_$SWIFTTAG.orig-swift-nio-ssl.zip
-#mv swift-nio-ssl-$SWIFT_NIO_SSL_VERSION swift-nio-ssl
-
 if [ -f "../swiftlang_$SWIFTTAG.orig-swift-format.tar.gz" ];
 then
     echo "Found existing swiftlang_$SWIFTTAG.orig-swift-format.tar.gz"
@@ -445,15 +432,15 @@ tar -C swift-asn1 -xzf ../swiftlang_$SWIFTTAG.orig-swift-asn1.tar.gz --strip-com
 #tar -C wasi-libc -xzf ../swiftlang_$SWIFTTAG.orig-wasi-libc.tar.gz --strip-components=1
 
 
-#if [ -f "../swiftlang_$SWIFTTAG.orig-wasmkit.tar.gz" ];
-#then
-    #echo "Found existing swiftlang_$SWIFTTAG.orig-wasmkit.tar.gz"
-#else
-    #wget https://github.com/swiftwasm/WasmKit/archive/refs/tags/$WASMKIT_VERSION.tar.gz
-    #mv -f $WASMKIT_VERSION.tar.gz ../swiftlang_$SWIFTTAG.orig-wasmkit.tar.gz
-#fi
-#mkdir wasmkit
-#tar -C wasmkit -xzf ../swiftlang_$SWIFTTAG.orig-wasmkit.tar.gz --strip-components=1
+if [ -f "../swiftlang_$SWIFTTAG.orig-wasmkit.tar.gz" ];
+then
+    echo "Found existing swiftlang_$SWIFTTAG.orig-wasmkit.tar.gz"
+else
+    wget https://github.com/swiftwasm/WasmKit/archive/refs/tags/$WASMKIT_VERSION.tar.gz
+    mv -f $WASMKIT_VERSION.tar.gz ../swiftlang_$SWIFTTAG.orig-wasmkit.tar.gz
+fi
+mkdir wasmkit
+tar -C wasmkit -xzf ../swiftlang_$SWIFTTAG.orig-wasmkit.tar.gz --strip-components=1
 
 
 if [ -f "../swiftlang_$SWIFTTAG.orig-swift-testing.tar.gz" ];
